@@ -10,6 +10,4 @@ def process(hub, renderer, value):
     """
     Take a renderer adn a value, process it, and return the processed value
     """
-    print(renderer)
-    print(value)
     return getattr(hub, f"config.render.{renderer}.render")(value)
